skhubness.neighbors.KDTree
==========================

.. currentmodule:: skhubness.neighbors

.. autoclass:: KDTree

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KDTree.__init__
      ~KDTree.get_arrays
      ~KDTree.get_n_calls
      ~KDTree.get_tree_stats
      ~KDTree.kernel_density
      ~KDTree.query
      ~KDTree.query_radius
      ~KDTree.reset_n_calls
      ~KDTree.two_point_correlation
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~KDTree.data
      ~KDTree.idx_array
      ~KDTree.node_bounds
      ~KDTree.node_data
      ~KDTree.sample_weight
      ~KDTree.sum_weight
      ~KDTree.valid_metrics
   
   